@@ -49,14 +49,9 @@ class DataPoint:
         return self.camera_path.joinpath("semantic_segmentation.png").exists()
 
     @modalities.textual_modality
-    def semantic_segmentation_color_map(self) -> modalities.TextualModality:
+    def semantic_segmentation_metadata(self) -> modalities.TextualModality:
         return modalities.TextualModality(factory_name="segmentation", file_name="semantic_segmentation_metadata.json")
 
-    @property
-    @deprecated(reason="Modality name changed to 'semantic_segmentation_color_map', please use new name instead")
-    def semantic_segmentation_metadata(self):
-        return self.semantic_segmentation_color_map
-
     @modalities.visual_modality
     def depth(self) -> modalities.VisualModality:
         return modalities.VisualModality("depth.exr")
