@@ -12,7 +12,7 @@ class DataPoint(base.DataPoint):
         return modalities.TextualModality(factory_name="actors", file_name="actor_metadata.json")
 
     @property
-    @deprecated(reason="(Modality name changed to 'actors' (For HIC datapoints only!), please use new name instead")
+    @deprecated(reason="Modality name changed to 'actors' (For HIC datapoints only!), please use new name instead")
     def actor_metadata(self) -> modalities.TextualModality:
         return self.actors
 
