@@ -1,7 +1,7 @@
 from dependency_injector import containers, providers
 
 from datagen.imaging.opencv import OpenCVImagingLibrary
-from datagen.modalities import textual
+from datagen.modalities import textual as textual_modalities
 
 
 class VisualModalitiesContainer(containers.DeclarativeContainer):
@@ -26,7 +26,7 @@ def read_textual_modality(
     )
 
 
-class ModalitiesContainer(containers.DeclarativeContainer):
+class DatapointModalitiesContainer(containers.DeclarativeContainer):
 
     __self__ = providers.Self()
 
@@ -37,7 +37,11 @@ class ModalitiesContainer(containers.DeclarativeContainer):
     read_visual_modality = providers.Callable(read_visual_modality, modalities_container=__self__)
 
     textual = providers.Selector(
-        config.environment, identities=providers.Container(textual.IdentitiesModalitiesContainer)
+        config.environment,
+        hic=providers.Container(textual_modalities.HICModalitiesContainer),
+        identities=providers.Container(textual_modalities.IdentitiesModalitiesContainer)
     )
 
     read_textual_modality = providers.Callable(read_textual_modality, modalities_container=__self__)
+
+    wiring_config = containers.WiringConfiguration(packages=[textual_modalities])
