@@ -63,6 +63,9 @@ class VisualModality(Modality):
 
 class VisualModalityDescriptor(ModalityDescriptor):
     def _read(self, dp, modality: VisualModality, modality_file_path: Path):
-        return dp.modalities_container.read_visual_modality(
-            modality_file_path=modality_file_path, **modality.read_context
-        )
+        if modality_file_path.exists():
+            return dp.modalities_container.read_visual_modality(
+                modality_file_path=modality_file_path, **modality.read_context
+            )
+        else:
+            return None
