@@ -1,3 +1,5 @@
+from typing import Optional
+
 import marshmallow_dataclass
 from marshmallow import pre_load
 
@@ -32,11 +34,12 @@ class Sensor:
 class CameraMetadata:
     camera_name: str
     camera_type: str
-    location: NumpyArray
-    orientation: Orientation
+    focal_length: Optional[float]
+    sensor: Sensor
     resolution_px: NumpyArray
     aspect_px: NumpyArray
+    location: NumpyArray
+    orientation: Orientation
     fov: FOV
-    sensor: Sensor
     intrinsic_matrix: NumpyArray
     extrinsic_matrix: NumpyArray
