@@ -26,7 +26,7 @@ class KeypointsModalityContainer(containers.DeclarativeContainer):
     from .keypoints import v1, v2
 
     create = providers.FactoryAggregate(
-        {1: modality_dataclass_factory(clazz=v1.Keypoints), 2: modality_dataclass_factory(clazz=v2.Keypoints)}
+        {1: modality_dataclass_factory(clazz=v1.SceneKeypoints), 2: modality_dataclass_factory(clazz=v2.SceneKeypoints)}
     )
 
 
